'''Application settings for django-autoconfig.'''

from django.conf import settings

#: Extra URLs for autourlconf
AUTOCONFIG_EXTRA_URLS = getattr(settings, 'AUTOCONFIG_EXTRA_URLS', ())

#: A list/tuple of apps to exclude from the autourlconf
AUTOCONFIG_URLCONF_EXCLUDE_APPS = getattr(settings, 'AUTOCONFIG_URLCONF_EXCLUDE_APPS', ())

#: A view name (suitable for reverse()) that the base / will redirect to.
AUTOCONFIG_INDEX_VIEW = getattr(settings, 'AUTOCONFIG_INDEX_VIEW', None)

#: A dictionary from app name to the prefix it should be mapped to
#: The default for each app is the app name itself, with _ replaced by -
AUTOCONFIG_URL_PREFIXES = getattr(settings, 'AUTOCONFIG_URL_PREFIXES', {})



'''This module can be set as a ROOT_URLCONF (or included into one).'''

from django.conf import settings

from .app_settings import AUTOCONFIG_EXTRA_URLS, AUTOCONFIG_INDEX_VIEW, AUTOCONFIG_URL_PREFIXES, AUTOCONFIG_URLCONF_EXCLUDE_APPS

from .autoconfig import configure_urls

apps = [app for app in settings.INSTALLED_APPS if app not in AUTOCONFIG_URLCONF_EXCLUDE_APPS]

urlpatterns = configure_urls(  # pylint: disable=C0103
    apps + list(AUTOCONFIG_EXTRA_URLS),
    index_view=AUTOCONFIG_INDEX_VIEW,
    prefixes=AUTOCONFIG_URL_PREFIXES,
)

if settings.DEBUG:
    media_url = getattr(settings, 'MEDIA_URL', None)
    media_root = getattr(settings, 'MEDIA_ROOT', None)
    if media_url and media_root:
        from django.conf.urls.static import static
        urlpatterns += static(media_url, document_root=media_root)



from django.conf.urls import url
try:
    from django.conf.urls import patterns
except ImportError:
    def patterns(_, *args):
        return args

from django_autoconfig.tests.app_urls.views import index

urlpatterns = patterns('',
    url(r'^index/$', index, name='test-app-index'),
)



SETTINGS = {
    'TEMPLATES': [
        {
            'BACKEND': 'django.template.backends.django.DjangoTemplates',
            'APP_DIRS': True,
            'OPTIONS': {
                'context_processors': [
                    'django.template.context_processors.request',
                ],
            },
        },
    ],
}



import django


# Django 2.0 completely removed MIDDLEWARE_CLASSES. MIDDLEWARE shall be used instead.
if django.VERSION >= (2, 0):
    SETTINGS = {
        'MIDDLEWARE': ['my.middleware'],
    }
else:
    SETTINGS = {
        'MIDDLEWARE_CLASSES': ['my.middleware'],
    }



from django_autoconfig.autoconfig import OrderingRelationship

RELATIONSHIPS = [
    OrderingRelationship(
        'INSTALLED_APPS',
        'django_autoconfig.tests.app_relationship',
        before=['django_autoconfig.tests.app1'],
    ),
    OrderingRelationship(
        'INSTALLED_APPS',
        'django_autoconfig.tests.app_relationship',
        before=['django_autoconfig.tests.app3'],
        add_missing=True,
    ),
    OrderingRelationship(
        'INSTALLED_APPS',
        'django_autoconfig.tests.app_relationship',
        before=['django_autoconfig.tests.app4'],
        add_missing=False,
    ),
    OrderingRelationship(
        'INSTALLED_APPS',
        'django_autoconfig.tests.app2',
        after=['django_autoconfig.tests.app3'],
    ),
]



import django
from django.conf.urls import include, url
try:
    from django.conf.urls import patterns
except ImportError:
    def patterns(_, *args):
        return args
from django.contrib import admin

admin.autodiscover()
# admin.site.urls should not be included since Django 1.9 (and breaks since Django 2.0).
# Additionally, urlpatterns shall be an array since Django 1.8.
if django.VERSION >= (1, 9):
    urlpatterns = [
        url('', admin.site.urls),
    ]
else:
    urlpatterns = patterns('',
        url('', include(admin.site.urls)),
    )
